@@ -275,14 +275,14 @@ void Fd_Element_Var_V_To_I(Range *i,Range *v,WamWord **l)
 
 {
  WamWord *fdv_adr;
- int      n;
+ long     n;
  int      j;
 
  Vector_Allocate(i->vec);
  Vector_Empty(i->vec);
                                         /* when V or L changes -> update I */
 
- n=(int) *l;
+ n=(long) *l;
 
  for(j=1;j<=n;j++)
     {
@@ -325,7 +325,7 @@ Bool Fd_Atmost(int n,WamWord **array,int v)
 {
  WamWord **p;
  WamWord   word=Tag_Value(INT,v);
- int       size=(int) array[0];
+ long      size=(long) array[0];
  int       nb=0;
  int       i;
 
@@ -368,7 +368,7 @@ Bool Fd_Atleast(int n,WamWord **array,int v)
 
 {
  WamWord **p;
- int       size=(int) array[0];
+ long      size=(long) array[0];
  int       nb=size;
  int       i;
 
@@ -412,7 +412,7 @@ Bool Fd_Exactly(int n,WamWord **array,int v)
 {
  WamWord **p;
  WamWord   word=Tag_Value(INT,v);
- int       size=(int) array[0];
+ long      size=(long) array[0];
  int       nb1=0,nb2=size;
  int       i;
 
