@@ -795,7 +795,7 @@ Bool Fd_Sel_Array_Pick_Var_4(WamWord sel_array_word,WamWord method_word,
  WamWord **array;
  WamWord **p,**end;
  CmpFct    cmp_meth;
- int       n;
+ long      n;
  int       i;
  WamWord  *fdv_adr;
  WamWord **res_elem=NULL;
@@ -807,7 +807,7 @@ Bool Fd_Sel_Array_Pick_Var_4(WamWord sel_array_word,WamWord method_word,
 
  array=(WamWord **) (Cstr_Stack + Rd_Integer_Check(sel_array_word));
 
- n=(int) array[0];
+ n=(long) array[0];
  if (n==0)
      return FALSE;
 
