@@ -595,7 +595,7 @@ Bool Number_Atom_2(WamWord number_word,WamWord atom_word)
  Deref(number_word,word,tag,adr)
  if (tag==INT)
     {
-     sprintf(glob_buff,"%d",UnTag_INT(word));
+     sprintf(glob_buff,"%ld",UnTag_INT(word));
      return Un_String_Check(glob_buff,atom_word);
     }
 
@@ -646,7 +646,7 @@ from_nb:
  Deref(number_word,word,tag,adr)
  if (tag==INT)
     {
-     sprintf(glob_buff,"%d",UnTag_INT(word));
+     sprintf(glob_buff,"%ld",UnTag_INT(word));
      return Un_Chars(glob_buff,chars_word);
     }
 
@@ -703,7 +703,7 @@ from_nb:
  Deref(number_word,word,tag,adr)
  if (tag==INT)
     {
-     sprintf(glob_buff,"%d",UnTag_INT(word));
+     sprintf(glob_buff,"%ld",UnTag_INT(word));
      return Un_Codes(glob_buff,codes_word);
     }
 
