@@ -235,7 +235,7 @@
 /* RD_INTEGER_CHECK                                                        */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Rd_Integer_Check(WamWord start_word)
+long Rd_Integer_Check(WamWord start_word)
 
 {
  WamWord word,tag,*adr;
@@ -257,7 +257,7 @@ int Rd_Integer_Check(WamWord start_word)
 /* RD_INTEGER                                                              */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Rd_Integer(WamWord start_word)
+long Rd_Integer(WamWord start_word)
 
 {
  WamWord word,tag,*adr;
@@ -274,10 +274,10 @@ int Rd_Integer(WamWord start_word)
 /* RD_POSITIVE_CHECK                                                       */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Rd_Positive_Check(WamWord start_word)
+long Rd_Positive_Check(WamWord start_word)
 
 {
- int n=Rd_Integer_Check(start_word);
+ long n=Rd_Integer_Check(start_word);
 
  if (n<0)
      Pl_Err_Domain(domain_not_less_than_zero,start_word);
@@ -292,7 +292,7 @@ int Rd_Positive_Check(WamWord start_word)
 /* RD_POSITIVE                                                             */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Rd_Positive(WamWord start_word)
+long Rd_Positive(WamWord start_word)
 
 {
  return Rd_Integer(start_word);
@@ -1464,7 +1464,7 @@ void Check_For_Un_Variable(WamWord start_word)
 /* UN_INTEGER_CHECK                                                        */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-Bool Un_Integer_Check(int value,WamWord start_word)
+Bool Un_Integer_Check(long value,WamWord start_word)
 
 {
  CHECK_FOR_UN_INTEGER
@@ -1479,7 +1479,7 @@ Bool Un_Integer_Check(int value,WamWord start_word)
 /* UN_INTEGER                                                              */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-Bool Un_Integer(int value,WamWord start_word)
+Bool Un_Integer(long value,WamWord start_word)
 
 {
  return Get_Integer(value,start_word);
@@ -1492,7 +1492,7 @@ Bool Un_Integer(int value,WamWord start_word)
 /* UN_POSITIVE_CHECK                                                       */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-Bool Un_Positive_Check(int value,WamWord start_word)
+Bool Un_Positive_Check(long value,WamWord start_word)
 
 {
  CHECK_FOR_UN_POSITIVE
@@ -1507,7 +1507,7 @@ Bool Un_Positive_Check(int value,WamWord start_word)
 /* UN_POSITIVE                                                             */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-Bool Un_Positive(int value,WamWord start_word)
+Bool Un_Positive(long value,WamWord start_word)
 
 {
  return Get_Integer(value,start_word);
@@ -1551,11 +1551,11 @@ Bool Un_Float(double value,WamWord start_word)
 Bool Un_Number_Check(double value,WamWord start_word)
 
 {
- int n;
+ long n;
 
  CHECK_FOR_UN_NUMBER
 
- n=(int) value;
+ n=(long) value;
 
  return (n==value) ? Get_Integer(n,word) : Get_Float(value,word);
 }
@@ -1570,9 +1570,9 @@ Bool Un_Number_Check(double value,WamWord start_word)
 Bool Un_Number(double value,WamWord start_word)
 
 {
- int n;
+ long n;
 
- n=(int) value;
+ n=(long) value;
 
  return (n==value) ? Get_Integer(n,start_word) : Get_Float(value,start_word);
 }
@@ -2098,7 +2098,7 @@ Bool Un_Callable(int func,int arity,WamWord *arg,WamWord start_word)
 /* MK_INTEGER                                                              */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-WamWord Mk_Integer(int value)
+WamWord Mk_Integer(long value)
 
 {
  return Put_Integer(value);
@@ -2111,7 +2111,7 @@ WamWord Mk_Integer(int value)
 /* MK_POSITIVE                                                             */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-WamWord Mk_Positive(int value)
+WamWord Mk_Positive(long value)
 
 {
  return Put_Integer(value);
@@ -2142,7 +2142,7 @@ WamWord Mk_Number(double value)
 {
  int n;
 
- n=(int) value;
+ n=(long) value;
 
  if (n==value)
      return Put_Integer(n);
