@@ -38,10 +38,10 @@
 /* Function Prototypes             */
 /*---------------------------------*/
 
-int       Rd_Integer_Check      (WamWord start_word);
-int       Rd_Integer            (WamWord start_word);
-int       Rd_Positive_Check     (WamWord start_word);
-int       Rd_Positive           (WamWord start_word);
+long      Rd_Integer_Check      (WamWord start_word);
+long      Rd_Integer            (WamWord start_word);
+long      Rd_Positive_Check     (WamWord start_word);
+long      Rd_Positive           (WamWord start_word);
 double    Rd_Float_Check        (WamWord start_word);
 double    Rd_Float              (WamWord start_word);
 double    Rd_Number_Check       (WamWord start_word);
@@ -108,10 +108,10 @@ void      Check_For_Un_Variable (WamWord start_word);
 
 
 
-Bool      Un_Integer_Check      (int    value,WamWord start_word);
-Bool      Un_Integer            (int    value,WamWord start_word);
-Bool      Un_Positive_Check     (int    value,WamWord start_word);
-Bool      Un_Positive           (int    value,WamWord start_word);
+Bool      Un_Integer_Check      (long   value,WamWord start_word);
+Bool      Un_Integer            (long   value,WamWord start_word);
+Bool      Un_Positive_Check     (long   value,WamWord start_word);
+Bool      Un_Positive           (long   value,WamWord start_word);
 Bool      Un_Float_Check        (double value,WamWord start_word);
 Bool      Un_Float              (double value,WamWord start_word);
 Bool      Un_Number_Check       (double value,WamWord start_word);
@@ -154,8 +154,8 @@ Bool      Un_Callable           (int func,int arity,WamWord *arg,
 
 
 
-WamWord   Mk_Integer            (int    value);
-WamWord   Mk_Positive           (int    value);
+WamWord   Mk_Integer            (long   value);
+WamWord   Mk_Positive           (long   value);
 WamWord   Mk_Float              (double value);
 WamWord   Mk_Number             (double value);
 WamWord   Mk_Atom               (int    value);
