@@ -38,8 +38,13 @@
 
 #define BANK_NAME_OFFSET_LENGTH    15
 
+#if WORD_SIZE==32
 #define HEXADECIMAL_LENGTH         10
 #define DECIMAL_LENGTH             10
+#else
+#define HEXADECIMAL_LENGTH         20
+#define DECIMAL_LENGTH             20
+#endif
 #define VALUE_PART_LENGTH          BANK_NAME_OFFSET_LENGTH
 
 #define SEPARATOR_LIST             " ,[]\n"
@@ -116,7 +121,7 @@ WamWord  *Read_Bank_Adr         (Bool only_stack,int arg_nb,
                                  char **bank_name);
 
 static 
-int       Read_An_Integer       (int arg_nb);
+long      Read_An_Integer       (int arg_nb);
 
 static 
 void      Print_Bank_Name_Offset(char *prefix,char *bank_name,int offset);
@@ -763,11 +768,11 @@ static WamWord *Read_Bank_Adr(Bool only_stack,int arg_nb,char **bank_name)
 /* READ_AN_INTEGER                                                         */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-static int Read_An_Integer(int arg_nb)
+static long Read_An_Integer(int arg_nb)
 
 {
  char *p;
- int   val=0;
+ long  val=0;
 
  val=strtol(read_arg[arg_nb],&p,0);
  if (*p)
