@@ -817,7 +817,7 @@ static DynCInf *Scan_Dynamic_Pred_Next(DynScan *scan)
 {
  long    *xxx_ind_chain,*var_ind_chain;
  DynCInf *xxx_clause,   *var_clause;
- int      xxx_nb,        var_nb;
+ long     xxx_nb,        var_nb;
  DynCInf *clause;
 
 #ifdef DEBUG
