@@ -407,7 +407,7 @@ static Bool Unif_Flag(int i,WamWord value_word)
 
 {
  int atom= -1;
- int n;
+ long n;
 
  switch(i)
     {
