@@ -57,7 +57,7 @@ static
 char     *Arg_Atom              (WamWord **lst_adr);
 
 static
-int       Arg_Integer           (WamWord **lst_adr);
+long      Arg_Integer           (WamWord **lst_adr);
 
 static 
 double    Arg_Float             (WamWord **lst_adr);
@@ -126,9 +126,9 @@ static void Format(StmInf *pstm,char *format,WamWord *lst_adr)
  WamWord  word;
  Bool     has_n;
  long     generic;
- int      n,n1;
+ long     n,n1;
  char    *p;
- int      x;
+ long     x;
  double   d;
  int      lg,stop;
  int      i,k;
@@ -248,9 +248,9 @@ static void Format(StmInf *pstm,char *format,WamWord *lst_adr)
                  d=Arg_Float(&lst_adr);
 
                  if (has_n)
-                     sprintf(buff,"%%.%d%c",n,x);
+                     sprintf(buff,"%%.%ld%c",n,(char) x);
                   else
-                     sprintf(buff,"%%%c",x);
+                     sprintf(buff,"%%%c",(char) x);
 
                  Stream_Printf(pstm,buff,d);
                  break;
@@ -261,7 +261,7 @@ static void Format(StmInf *pstm,char *format,WamWord *lst_adr)
 
                  if (n==0 && *format=='d')
                     {
-                     Stream_Printf(pstm,"%d",x);
+                     Stream_Printf(pstm,"%ld",x);
                      break;
                     }
 
@@ -271,14 +271,14 @@ static void Format(StmInf *pstm,char *format,WamWord *lst_adr)
                      x= -x;
                     }
 
-                 sprintf(buff,"%d",x);
+                 sprintf(buff,"%ld",x);
                  lg=strlen(buff)-n;
                  if (lg<=0)
                     {
                      Stream_Puts("0.",pstm);
                      for(i=0;i< -lg;i++)
                          Stream_Putc('0',pstm);
-                     Stream_Printf(pstm,"%d",x);
+                     Stream_Printf(pstm,"%ld",x);
                      break;
                     }
 
@@ -464,7 +464,7 @@ static char *Arg_Atom(WamWord **lst_adr)
 /* ARG_INTEGER                                                             */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-static int Arg_Integer(WamWord **lst_adr)
+static long Arg_Integer(WamWord **lst_adr)
 
 {
  WamWord word;
