@@ -325,7 +325,7 @@ static void Scan_Number(StmInf *pstm,Bool integer_only)
                                                          /* integer number */
  token.type=TOKEN_INTEGER;
  *p++='\0';
- sscanf(token.name,"%d",&token.int_num);
+ sscanf(token.name,"%ld",&token.int_num);
  if (lg!=1 || token.int_num!=0 || strchr("'bBoOxX",c)==NULL)
      goto push_back;
 
