@@ -59,7 +59,7 @@ typedef struct
      TypTok type;
      char   name[SCAN_BIG_BUFFER]; /* for VARIABLE NAME STRING BACK_QUOTED */
      int    punct;                 /* for PUNCTUATION                      */
-     int    int_num;               /* for INTEGER                          */
+     long   int_num;               /* for INTEGER                          */
      double float_num;             /* for FLOAT                            */
      int    line;                  /* source line of the token             */
      int    col;                   /* source column of the token           */
