@@ -1043,13 +1043,19 @@ int Stream_Getc_No_Echo(StmInf *pstm)
 
  Before_Reading(pstm,file)
 
- if (!PB_Is_Empty(pstm->pb_char))
+ if (!PB_Is_Empty(pstm->pb_char)) {
      PB_Pop(pstm->pb_char,c)
-  else
+ } else {
+#ifdef M_alpha_linux
+     Save_Machine_Regs(bug_reg_buffer);
+     bug_reg_buffer[NB_OF_USED_MACHINE_REGS]=1; /* is valid */
+#endif
 #ifndef NO_USE_LINEDIT
      c=TTY_Getc_No_Echo((TTYInf *) file);
+ }
 #else
      c=pstm->fct_getc((FILE *) file);
+ }
 
  if (c!='\n')
      while(pstm->fct_getc((FILE *) file)>=' ')
@@ -1085,11 +1091,15 @@ int Stream_Getc(StmInf *pstm)
 
  Before_Reading(pstm,file)
 
- if (!PB_Is_Empty(pstm->pb_char))
+ if (!PB_Is_Empty(pstm->pb_char)) {
      PB_Pop(pstm->pb_char,c)
-  else
+ } else {
+#ifdef M_alpha_linux
+     Save_Machine_Regs(bug_reg_buffer);
+     bug_reg_buffer[NB_OF_USED_MACHINE_REGS]=1; /* is valid */
+#endif
      c=(*pstm->fct_getc)(file);
-
+ }
  if (c==EOF)
      pstm->eof_reached=TRUE;
 
