@@ -106,7 +106,7 @@ static
 void      Show_Atom             (int context,int atom);
 
 static 
-void      Show_Integer          (int x);
+void      Show_Integer          (long x);
 
 static
 void      Show_Fd_Variable      (WamWord *fdv_adr);
@@ -403,12 +403,12 @@ static void Show_Atom(int context,int atom)
 /* SHOW_INTEGER                                                            */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-static void Show_Integer(int x)
+static void Show_Integer(long x)
 
 {
  char str[32];
 
- sprintf(str,"%d",x);
+ sprintf(str,"%ld",x);
  Out_String(str);
 
  last_writing=W_NUMBER;
