@@ -35,4 +35,4 @@
 /*---------------------------------*/
 
 #define RANGE_TOP_STACK            CS
-#define INTERVAL_MAX_INTEGER       INT_GREATEST_VALUE
+#define INTERVAL_MAX_INTEGER       ((int)((1L<<(32-TAG_SIZE-1))-1)) /* only 32 bits */
