@@ -203,6 +203,15 @@ void Reset_Prolog_In_Signal(void)
 
 {
  reg_bank=save_reg_bank;
+#ifdef M_alpha_linux
+ /* reset the possible trashed $10 (in a call to fgetc) */
+ if (bug_reg_buffer[NB_OF_USED_MACHINE_REGS] == 1) {
+   /*   fprintf (stdout, "restoring registers\n"); */
+    Restore_Machine_Regs(bug_reg_buffer);
+    bug_reg_buffer[NB_OF_USED_MACHINE_REGS]=0; /* invalidate */
+ }
+#endif
+
 }
 
 
