@@ -71,6 +71,13 @@ typedef CodePtr WamCont;               /* a continuation is a code pointer */
        long   *base_fl;               /* overwritten by foreign if present */
        double *base_fd;               /* overwritten by foreign if present */
 
+/* we need some extra space to save our registers while in a libc routine!
+ * otherwise they are not correct after a signal has raised.
+ */
+#ifdef M_alpha_linux
+       unsigned long bug_reg_buffer[32];
+#endif
+
 #else
 
 extern int    os_argc;
@@ -81,8 +88,11 @@ extern char   glob_buff[];
 extern long   *base_fl;
 extern double *base_fd;
 
+#ifdef M_alpha_linux
+extern unsigned long bug_reg_buffer[];
 #endif
 
+#endif
 
 
 
