@@ -54,6 +54,12 @@ void Call_Compiled(CodePtr codep)
 
  register WamWord *rb asm("%ebx")=reg_bank;
 
+#elif defined(M_mips_irix)
+ register WamWord *rb asm("$16")=reg_bank;
+
+#elif defined(M_alpha_linux) || defined(M_alpha_osf)
+ register WamWord *rb asm("$9")=reg_bank;
+
 #elif defined(M_ix86_win32)
 
  _asm mov ebx,reg_bank
