@@ -62,6 +62,10 @@
 #endif
 
 
+#if 0
+#define DEBUG
+#endif
+
 
 
 
@@ -200,7 +204,7 @@ void Init_Machine(void)
 void M_Allocate_Stacks(void)
 
 {
- int       len=0;
+ unsigned  len=0;
  WamWord  *addr;
  int       i;
 
@@ -231,6 +235,10 @@ void M_Allocate_Stacks(void)
 
 #ifndef M_ix86_win32
 #include <sys/mman.h>
+
+#if !defined(MAP_ANON) && defined(MAP_ANONYMOUS)
+#define MAP_ANON MAP_ANONYMOUS
+#endif
 #endif
 
 /*-------------------------------------------------------------------------*/
@@ -240,10 +248,10 @@ void M_Allocate_Stacks(void)
 void M_Allocate_Stacks(void)
 
 {
- int      len=0;
+ unsigned len=0;
  WamWord *addr;
  int      i;
-#if !defined(M_alpha_osf) && !defined(M_ix86_win32)
+#ifndef MAP_ANON
  int      fd;
 
  fd=open("/dev/zero",0);
@@ -262,34 +270,55 @@ void M_Allocate_Stacks(void)
     }
 
  addr=(WamWord *) M_MMAP_HIGH_ADR;
+#ifdef M_MMAP_HIGH_ADR_ALT
+ i=0;
+try_mmap:
+#endif
+#ifdef DEBUG
+ DBGPRINTF("trying at high addr:%lx\n",(long) addr);
+#endif
  addr=(WamWord *) Round_Down((long) addr,getpagesize());
  addr-=len;
+ len*=sizeof(WamWord);
 
 #ifdef M_ix86_win32
- addr=(WamWord *) VirtualAlloc(addr,len*sizeof(WamWord),
+ addr=(WamWord *) VirtualAlloc(addr,len,
                                MEM_RESERVE|MEM_COMMIT,PAGE_READWRITE);
 #else
- addr=(WamWord *) mmap((caddr_t) addr,len*sizeof(WamWord),
+ addr=(WamWord *) mmap((caddr_t) addr,len,
                        PROT_READ|PROT_WRITE,
-#ifndef M_alpha_osf
-                       MAP_PRIVATE|MAP_FIXED,fd,
+#ifdef MAP_ANON
+                       MAP_PRIVATE|MAP_ANON,-1,
 #else
-                       MAP_ANON|MAP_PRIVATE|MAP_FIXED,-1,
+                       MAP_PRIVATE,fd,
 #endif
                        0);
 #endif
 
 
 #ifdef DEBUG
- DBGPRINTF("start addr:%lx   size:%ld\n",addr,len*sizeof(WamWord));
+ DBGPRINTF("start addr:%lx   size:%d\n",(long) addr,len);
 #endif
 
 #ifdef M_ix86_win32
  if (addr==NULL)
 #else
- if ((long) addr<0)
+  if ((long) addr<0 || ((long) addr & (((1L<<TAG_SIZE)-1)<<VALUE_SIZE))!=0)
 #endif
+    {
+#ifdef M_MMAP_HIGH_ADR_ALT
+     if (i==0)
+        {
+         i=1;
+	 if ((long) addr>=0)
+             munmap(addr,len);
+         addr=(WamWord *) M_MMAP_HIGH_ADR_ALT;
+         goto try_mmap;
+	}
+#endif
+
      Fatal_Error(ERR_STACKS_ALLOCATION);
+    }
 
  for(i=0;i<NB_OF_STACKS;i++)
     {
@@ -419,7 +448,7 @@ void SIGSEGV_Handler(int sig,siginfo_t *sip)
 
 static void SIGSEGV_Handler(int sig,int code,struct sigcontext *scp)
 
-#elif defined(M_ix86_linux) || defined(M_powerpc_linux)
+#elif defined(M_ix86_linux) || defined(M_powerpc_linux) || defined(M_alpha_linux)
 #include <asm/sigcontext.h>
 
 #if 0   /* old linux */
@@ -443,6 +472,12 @@ static void SIGSEGV_Handler(int sig,int code, struct sigcontext *scp)
 
 void SIGSEGV_Handler(void)
 
+#elif defined(M_mips_irix)
+
+#include <signal.h>
+
+void SIGSEGV_Handler(int sig, int code, struct sigcontext *scp)
+
 #else
 
 static void SIGSEGV_Handler(int sig)
@@ -460,6 +495,11 @@ static void SIGSEGV_Handler(int sig)
 
  WamWord *addr=(WamWord *) (scp->sc_traparg_a0);
 
+#elif defined(M_alpha_linux)
+
+ WamWord *addr=(WamWord *) (scp.sc_fp_trigger_inst); /* why this one? */
+ /* WamWord *addr=(WamWord *) (scp.sc_traparg_a0); */
+ 
 #elif defined(M_sparc_solaris) || defined(M_ix86_solaris)
 
  WamWord *addr=(WamWord *) sip->si_addr;
@@ -480,6 +520,10 @@ static void SIGSEGV_Handler(int sig)
 
  WamWord *addr=(WamWord *) scp.regs->dar;
 
+#elif defined(M_mips_irix)
+
+ WamWord *addr=scp->sc_regs[16];
+
 #elif defined(M_ix86_win32)
 
  WamWord *addr=(WamWord *) fault_addr;
@@ -489,16 +533,16 @@ static void SIGSEGV_Handler(int sig)
  int i;
 
 #ifdef DEBUG
- DBGPRINTF("BAD ADDRESS:%x\n",addr);
-#endif
+ DBGPRINTF("BAD ADDRESS:%lx\n",(long) addr);
+#endif /* DEBUG */
 
  i=NB_OF_STACKS-1;
  if (addr<stk_tbl[i].stack+stk_tbl[i].size+page_size)
      while(i>=0)
         {
 #ifdef DEBUG
-         DBGPRINTF("STACK[%d].stack + size: %x\n",
-                i,stk_tbl[i].stack+stk_tbl[i].size);
+         DBGPRINTF("STACK[%d].stack + size: %lx\n",
+                i,(long) (stk_tbl[i].stack+stk_tbl[i].size));
 #endif
          if (addr>=stk_tbl[i].stack+stk_tbl[i].size)
              Stack_Overflow(i);
@@ -801,7 +845,7 @@ char *M_Host_Name_From_Name(char *host_name)
 {
  static char     buff[4096];
 #ifdef M_ix86_win32
-        long     length=sizeof(buff);
+ long            length=sizeof(buff);
 #endif
 #ifdef INET_MANAGEMENT
  struct hostent *host_entry;
