@@ -87,6 +87,15 @@ void      SIGSEGV_Handler       (void);
 
 #    define M_USED_REGS            {"g6","g7",0}
 
+#elif defined(M_mips_irix)
+
+#define M_USED_REGS                {"$16","$17","$18","$19","$20",\
+                                    "$21","$22","$23",0}
+
+#elif defined(M_alpha_linux)
+
+#    define M_USED_REGS            {"$9","$10","$11","$12","$13","$14",0}
+
 #elif defined(M_alpha_osf)
 
 #    define M_USED_REGS            {"$9","$10","$11","$12","$13","$14",0}
@@ -116,13 +125,15 @@ void      SIGSEGV_Handler       (void);
 #if defined(M_sparc_sunos) || defined(M_sparc_solaris) || \
     defined(M_ix86_linux)  || defined(M_powerpc_linux) || \
     defined(M_ix86_sco)    || defined(M_ix86_solaris)  || \
+    defined(M_mips_irix)   || \
     defined(M_ix86_win32)
 
 #   define M_USE_MMAP
-#   define M_MMAP_HIGH_ADR         0x0ffff000
+#   define M_MMAP_HIGH_ADR         0x0ffffff0
+#   define M_MMAP_HIGH_ADR_ALT     0x1ffffff0
 #   define M_Check_Stacks()
 
-#elif defined(M_alpha_osf)
+#elif defined(M_alpha_osf) || defined(M_alpha_linux)
 
 #   define M_USE_MMAP
 #   define M_MMAP_HIGH_ADR         0x3f800000000ULL
