@@ -202,7 +202,8 @@ void Find_Linked_Objects(void)
 #endif
      (*p->fct_init)();
 
-#ifdef M_powerpc_linux
+#if defined(M_powerpc_linux) || defined(M_alpha_linux) || \
+    defined(M_mips_irix)
      p=(ObjChain *) ((long *) p+1);
 #elif 0
      p=(ObjChain *)((char *) p+1);
