@@ -138,7 +138,7 @@ int main(void)
 
  if (WORD_SIZE!=(sizeof(long)*8))
     {
-     printf("Bad Value of WORD_SIZE - should be %d\n",(sizeof(long)*8));
+     printf("Bad Value of WORD_SIZE - should be %d\n",(int) (sizeof(long)*8));
      return 1;
     }
 
@@ -721,10 +721,10 @@ void Generate_Tags(FILE *f,FILE *g)
  fprintf(g,"#define Tag_Of(w)     \t\t((unsigned long) (w) & %#x)\n",(1<<tag_size)-1);
 
  fprintf(g,"\n");
- fprintf(g,"#define UnTag_Integer(w) \t((int) (((long) (w) >> %d)))\n",
+ fprintf(g,"#define UnTag_Integer(w) \t((long) (w) >> %d)\n",
          tag_size);
 
- fprintf(g,"#define UnTag_Unsigned(w)\t((unsigned) (((unsigned long) (w) >> %d)))\n",
+ fprintf(g,"#define UnTag_Unsigned(w)\t((unsigned long) (w) >> %d)\n",
          tag_size);
 
  fprintf(g,"#define UnTag_Stack(w)   \t((WamWord *) (((unsigned long) (w) >> %d) | STACK_MASK))\n",
