@@ -165,8 +165,8 @@ extern char    *reg_tbl[];
 #define Tag_Value(t,v)		(((unsigned long) (v) << 3) | (t))
 #define Tag_Of(w)     		((unsigned long) (w) & 0x7)
 
-#define UnTag_Integer(w) 	((int) (((long) (w) >> 3)))
-#define UnTag_Unsigned(w)	((unsigned) (((unsigned long) (w) >> 3)))
+#define UnTag_Integer(w) 	((long) (w) >> 3)
+#define UnTag_Unsigned(w)	((unsigned long) (w) >> 3)
 #define UnTag_Stack(w)   	((WamWord *) (((unsigned long) (w) >> 3) | STACK_MASK))
 #define UnTag_Malloc(w)  	((unsigned long) (((unsigned long) (w) >> 3) | MALLOC_MASK))
 
