@@ -183,7 +183,7 @@ Bool Get_Atom(int atom,WamWord start_word)
 /*                                                                         */
 /* Called by compiled prolog code.                                         */
 /*-------------------------------------------------------------------------*/
-Bool Get_Integer(int n,WamWord start_word)
+Bool Get_Integer(long n,WamWord start_word)
 
 {
  WamWord word,tag,*adr;
@@ -400,7 +400,7 @@ WamWord Put_Atom(int atom)
 /*                                                                         */
 /* Called by compiled prolog code.                                         */
 /*-------------------------------------------------------------------------*/
-WamWord Put_Integer(int n)
+WamWord Put_Integer(long n)
 
 {
  return Tag_Value(INT,n);
@@ -610,7 +610,7 @@ Bool Unify_Atom(int atom)
 /*                                                                         */
 /* Called by compiled prolog code.                                         */
 /*-------------------------------------------------------------------------*/
-Bool Unify_Integer(int n)
+Bool Unify_Integer(long n)
 
 {
  WamWord word,tag,*adr;
@@ -829,7 +829,7 @@ CodePtr Switch_On_Atom(SwtTbl t,int size)
 /*                                                                         */
 /* Called by compiled prolog code.                                         */
 /*-------------------------------------------------------------------------*/
-int Switch_On_Integer(void)
+long Switch_On_Integer(void)
 
 {
  return UnTag_INT(A(0));
@@ -882,8 +882,8 @@ void Load_Cut_Level(WamWord *word_adr)
 void Cut(WamWord b_word)
 
 {
- B=UnTag_REF(b_word);
-}
+ B=UnTag_REF(b_word);                    /* Tag_REF since stack adr as INT */
+}                                        /* only useful if STACK_MASK != 0 */
 
 
 
