@@ -124,8 +124,8 @@
 
           /* Integer */
 
-#define INT_GREATEST_VALUE         ((int) ((1  << (32-TAG_SIZE-1))-1))
-#define INT_LOWEST_VALUE           ((int) ((-INT_GREATEST_VALUE)-1))
+#define INT_GREATEST_VALUE         ((long) ((1L<<(WORD_SIZE-TAG_SIZE-1))-1))
+#define INT_LOWEST_VALUE           ((long) ((-INT_GREATEST_VALUE)-1))
 
 
 
@@ -220,7 +220,7 @@ void      Create_Swt_Stc_Element(SwtTbl t,int size,int func,int arity,
                                  CodePtr codep);
 
 Bool      Get_Atom              (int atom,WamWord start_word);
-Bool      Get_Integer           (int n,WamWord start_word);
+Bool      Get_Integer           (long n,WamWord start_word);
 Bool      Get_Float             (double n,WamWord start_word);
 Bool      Get_Nil               (WamWord start_word);
 Bool      Get_List              (WamWord start_word);
@@ -230,7 +230,7 @@ WamWord   Put_X_Variable        (void);
 WamWord   Put_Y_Variable        (WamWord *y_adr);
 WamWord   Put_Unsafe_Value      (WamWord start_word);
 WamWord   Put_Atom              (int atom);
-WamWord   Put_Integer           (int n);
+WamWord   Put_Integer           (long n);
 WamWord   Put_Float             (double n);
 WamWord   Put_Nil               (void);
 WamWord   Put_List              (void);
@@ -241,7 +241,7 @@ void      Unify_Void            (int n);
 Bool      Unify_Value           (WamWord start_word);
 Bool      Unify_Local_Value     (WamWord start_word);
 Bool      Unify_Atom            (int atom);
-Bool      Unify_Integer         (int n);
+Bool      Unify_Integer         (long n);
 Bool      Unify_Nil             (void);
 Bool      Unify_List            (void);
 Bool      Unify_Structure       (int func,int arity);
@@ -252,7 +252,7 @@ void      Deallocate            (void);
 CodePtr   Switch_On_Term        (CodePtr c_var,CodePtr c_atm,CodePtr c_int,
                                  CodePtr c_lst,CodePtr c_stc);
 CodePtr   Switch_On_Atom        (SwtTbl t,int size);
-int       Switch_On_Integer     (void);
+long      Switch_On_Integer     (void);
 CodePtr   Switch_On_Structure   (SwtTbl t,int size);
 
 void      Load_Cut_Level        (WamWord *word_adr);
