@@ -28,36 +28,26 @@
 
 #if defined(__unix__) || defined(__CYGWIN__)
 
+#include <unistd.h>
+#include <sys/ioctl.h>
+
 #if defined(HAVE_SYS_IOCTL_COMPAT_H)
 #include <sys/ioctl_compat.h>
 #endif
 
-#include <unistd.h>
-
-#if defined(sun) /* && defined(sparc) */ /* commented out for ix86/solaris */
-
-#include <sys/filio.h>
-int ioctl(int d, int request, ...);
-
-#else
-
-#include <sys/ioctl.h>
-
-#endif
-
-#if defined(HAVE_TERMIO_H)
-#include <termio.h>
-typedef struct termio TermIO;
-#define GETIOP TCGETA
-#define SETIOP TCSETA
-#elif defined(HAVE_TERMIOS_H)
+#if defined(HAVE_TERMIOS_H)
 #include <termios.h>
 typedef struct termios TermIO;
-#define GETIOP TIOCGETP
-#define SETIOP TIOCSETP
-#endif
+#define Gtty(fd,s) tcgetattr(fd,s)
+#define Stty(fd,s) tcsetattr(fd,TCSANOW,s)
+#else
+#include <termio.h>
+typedef struct termio TermIO;
+#define Gtty(fd,s) ioctl(fd,TCGETA,s)
+#define Stty(fd,s) ioctl(fd,TCSETA,s)
+#endif /* !HAVE_TERMIOS_H */
 
-#elif defined(_WIN32) && !defined(__CYGWIN__)
+#elif defined(_WIN32)
 
 #include <conio.h>
 
@@ -65,7 +55,6 @@ typedef struct termios TermIO;
 
 
 
-
 #define STTY_FILE
 #include "stty.h"
 #include "char_io.h"
@@ -113,13 +102,8 @@ static int           interrupt_key;
 
 
 #if defined(__unix__) || defined(__CYGWIN__)
-
 static
 void      Set_TTY_Mode          (TermIO *old,TermIO *new);
-
-#define Gtty(fd,s) ioctl(fd,GETIOP,s)
-#define Stty(fd,s) ioctl(fd,SETIOP,s)
-
 #endif
 
 
@@ -271,21 +255,16 @@ int LE_Which_Signal(int c)
 int LE_Kbd_Is_Not_Empty(int fd_in)
 
 {
-#if defined(__unix__)
+#if defined(__unix__) || defined(__CYGWIN__)
 
 #ifdef FIONREAD
  int nb_not_read;
  ioctl(0,FIONREAD,&nb_not_read);
  return nb_not_read!=0;
-#else /* SCO */
+#else
  return 0;
 #endif
 
-#elif defined(__CYGWIN__)
-
- return 0;
-
-
 #elif defined(_WIN32)
 
  if (w32gc_kbd_is_not_empty)
@@ -318,7 +297,7 @@ static void Set_TTY_Mode(TermIO *old,TermIO *new)
  new->c_cc[VMIN]=1;                                      /* MIN # of chars */
  new->c_cc[VTIME]=1;                                               /* TIME */
 
- new->c_cc[VINTR]=-1;                         /* desactivate SIGINT signal */
+ new->c_cc[VINTR]=-1;                          /* deactivate SIGINT signal */
 }
 
 #endif
