@@ -1,5 +1,8 @@
 #include "../../EnginePl/gp_config.h"
 #include "../../EnginePl/pl_params.h"
+
+#define OBJ_INIT initializer_fct
+
 #include "../../EnginePl/obj_chain.h"
 #include "mach.h"
 
@@ -341,7 +344,6 @@ long global_array[128];
 /* to define Data_Start() + Data_Stop */
 /* between obj_chain_start and obj_chain_stop */
 
-Declare_Object_Initializer(initializer_fct)
 static void initializer_fct()
 {
 }
