@@ -363,10 +363,10 @@ void Call_C_Start(char *fct_name,int nb_args)
 /* CALL_C_ARG_INT                                                          */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Call_C_Arg_Int(int offset,int int_val)
+int Call_C_Arg_Int(int offset,long int_val)
 
 {
- Inst_Printf("movl","$%d,%d(%%esp)",int_val,offset*4);
+ Inst_Printf("movl","$%ld,%d(%%esp)",int_val,offset*4);
 
  return 1;
 }
@@ -644,13 +644,13 @@ void Move_Ret_To_Foreign_D(int index)
 /* CMP_RET_AND_INT                                                         */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-void Cmp_Ret_And_Int(int int_val)
+void Cmp_Ret_And_Int(long int_val)
 
 {
  if (int_val==0)
      Inst_Printf("testl","%%eax,%%eax");
   else
-     Inst_Printf("cmpl","$%d,%%eax",int_val);
+     Inst_Printf("cmpl","$%ld,%%eax",int_val);
 }
 
 
@@ -766,12 +766,12 @@ void Dico_Long(char *name,int global,VType vtype,long value)
 #if defined(M_ix86_linux) || defined(M_ix86_sco)
          if (!global)
              Inst_Printf(".local",UN "%s",name);
-         Inst_Printf(".comm",UN "%s,%d,4",name,value*4);
+         Inst_Printf(".comm",UN "%s,%ld,4",name,value*4);
 #else
          if (!global)
-             Inst_Printf(".lcomm",UN "%s,%d",name,value*4);
+             Inst_Printf(".lcomm",UN "%s,%ld",name,value*4);
           else
-             Inst_Printf(".comm",UN "%s,%d",name,value*4);
+             Inst_Printf(".comm",UN "%s,%ld",name,value*4);
 #endif
          break;
 
@@ -782,7 +782,7 @@ void Dico_Long(char *name,int global,VType vtype,long value)
          Inst_Printf(".align","4");
 #endif
          Label_Printf(UN "%s:",name);
-         Inst_Printf(".long","%d",value);
+         Inst_Printf(".long","%ld",value);
          break;
     }
 }
