@@ -403,10 +403,10 @@ void Call_C_Start(char *fct_name,int nb_args)
 /* CALL_C_ARG_INT                                                          */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Call_C_Arg_Int(int offset,int int_val)
+int Call_C_Arg_Int(int offset,long int_val)
 
 {
- Inst_Printf("mov","[esp+%d],dword %d",offset*4,int_val);
+ Inst_Printf("mov","[esp+%d],dword %ld",offset*4,int_val);
 
  return 1;
 }
@@ -697,13 +697,13 @@ void Move_Ret_To_Foreign_D(int index)
 /* CMP_RET_AND_INT                                                         */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-void Cmp_Ret_And_Int(int int_val)
+void Cmp_Ret_And_Int(long int_val)
 
 {
  if (int_val==0)
      Inst_Printf("test","eax,eax");
   else
-     Inst_Printf("cmp","eax,%d",int_val);
+     Inst_Printf("cmp","eax,%ld",int_val);
 }
 
 
@@ -884,7 +884,7 @@ void Dico_Long(char *name,int global,VType vtype,long value)
              Inst_Printf("GLOBAL",UN "%s",name);
 
          Label_Printf(UN "%s:",name);
-         Inst_Printf("RESD","%d",value);
+         Inst_Printf("RESD","%ld",value);
          break;
 
      case INITIAL_VALUE:
@@ -900,7 +900,7 @@ void Dico_Long(char *name,int global,VType vtype,long value)
          Inst_Printf(".align","4");
 #endif
          Label_Printf(UN "%s:",name);
-         Inst_Printf("DD","%d",value);
+         Inst_Printf("DD","%ld",value);
          break;
     }
 }
