@@ -107,12 +107,13 @@ int       Switch_Cmp_Int        (SwtInf *c1,SwtInf *c2);
 void      Label_Printf          (char *label,...);
 void      Inst_Printf           (char *op,char *operands,...);
 void      Inst_Out              (char *op,char *operands);
+void	  Char_Out		(char c);
+void      String_Out	        (char *s);
+void      Int_Out               (int d);
 void      Parse_Arguments       (int argc,char *argv[]);
 void      Display_Help          (void);
 
 
-
-
 #define Check_Arg(i,str)      (strncmp(argv[i],str,strlen(argv[i]))==0)
 
 
@@ -441,6 +442,48 @@ void Inst_Out(char *op,char *operands)
 
 
 
+/*-------------------------------------------------------------------------*/
+/* CHAR_OUT                                                                */
+/*                                                                         */
+/* Only needed by mappers inlining assembly code.                          */
+/*-------------------------------------------------------------------------*/
+void Char_Out(char c)
+
+{
+ fprintf(file_out,"%c",c);
+}
+
+
+
+
+/*-------------------------------------------------------------------------*/
+/* STRING_OUT                                                              */
+/*                                                                         */
+/* Only needed by mappers inlining assembly code.                          */
+/*-------------------------------------------------------------------------*/
+void String_Out(char *s)
+
+{
+ fprintf(file_out,"%s",s);
+}
+
+
+
+
+/*-------------------------------------------------------------------------*/
+/* INT_OUT                                                                 */
+/*                                                                         */
+/* Only needed by mappers inlining assembly code.                          */
+/*-------------------------------------------------------------------------*/
+void Int_Out(int d)
+
+{
+ fprintf(file_out,"%d",d);
+}
+
+
+
+
 /*-------------------------------------------------------------------------*/
 /* PARSE_ARGUMENTS                                                         */
 /*                                                                         */
