@@ -29,12 +29,24 @@
 #include "../EnginePl/wam_regs.h"
 
 
+#if 0
+#define CHECK_PRINTF_ARGS
+#endif
+
+#ifdef CHECK_PRINTF_ARGS
+#define GCCPRINTF(x) __attribute__((format(printf,x,x+1)))
+#else
+#define GCCPRINTF(x)
+#endif
+
           /* defined in ma2asm.c */
 
-void      Label_Printf          (char *label,...);
-void      Inst_Printf           (char *op,char *operands,...);
+void      Label_Printf          (char *label,...) GCCPRINTF(1);
+void      Inst_Printf           (char *op,char *operands,...) GCCPRINTF(2);
 void      Inst_Out              (char *op,char *operands);
-
+void	  Char_Out              (char c);
+void      String_Out            (char *s);
+void      Int_Out               (int d);
 
 
           /* machined-dependent mapper (file: os_cpu.c) */
@@ -57,4 +69,12 @@ void      Inst_Out              (char *op,char *operands);
 
 #include "sparc_any.c"
 
+#elif defined(M_mips_irix)
+
+#include "mips_irix.c"
+
+#elif defined(M_alpha_linux) || defined(M_alpha_osf)
+
+#include "alpha_any.c"
+
 #endif
