@@ -584,7 +584,7 @@ static int Scanner(void)
 
 {
  char   *p,*p1;
- int     i;
+ long    i;
  double  d;
  double strtod();
 
