@@ -74,7 +74,7 @@ typedef struct
 
 typedef struct
     {
-     int       int_val;
+     long      int_val;
      char     *label;
     }SwtInf;
 
