@@ -72,7 +72,7 @@ void      Move_To_Reg_X         (int index);
 void      Move_To_Reg_Y         (int index);
 
 void      Call_C_Start          (char *fct_name,int nb_args);
-int       Call_C_Arg_Int        (int offset,int int_val);
+int       Call_C_Arg_Int        (int offset,long int_val);
 int       Call_C_Arg_Double     (int offset,double dbl_val);
 int       Call_C_Arg_String     (int offset,int str_no);
 int       Call_C_Arg_Mem_L      (int offset,int adr_of,char *name,int index);
@@ -90,7 +90,7 @@ void      Move_Ret_To_Reg_X     (int index);
 void      Move_Ret_To_Reg_Y     (int index);
 void      Move_Ret_To_Foreign_L (int index);
 void      Move_Ret_To_Foreign_D (int index);
-void      Cmp_Ret_And_Int       (int int_val);
+void      Cmp_Ret_And_Int       (long int_val);
 void      Jump_If_Equal         (char *label);
 void      Jump_If_Greater       (char *label);
 
