@@ -393,15 +393,15 @@ void Call_C_Start(char *fct_name,int nb_args)
 /* CALL_C_ARG_INT                                                          */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Call_C_Arg_Int(int offset,int int_val)
+int Call_C_Arg_Int(int offset,long int_val)
 
 {
  if (LITTLE_INT(int_val))
-     Inst_Printf("li","%d,%d",offset+3,int_val);
+     Inst_Printf("li","%d,%ld",offset+3,int_val);
  else
    {
-    Inst_Printf("lis","%d,%#x",offset+3,int_val>>16);
-    Inst_Printf("ori","%d,%d,%#x",offset+3,offset+3,int_val & 0xFFFF);
+    Inst_Printf("lis","%ld,%#x",offset+3,int_val>>16);
+    Inst_Printf("ori","%d,%ld,%#x",offset+3,offset+3,int_val & 0xFFFF);
    }
 
  return 1;
@@ -675,15 +675,15 @@ void Move_Ret_To_Foreign_D(int index)
 /* CMP_RET_AND_INT                                                         */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-void Cmp_Ret_And_Int(int int_val)
+void Cmp_Ret_And_Int(long int_val)
 
 {
  if (LITTLE_INT(int_val))
-     Inst_Printf("cmpwi","1,3,%d",int_val);
+     Inst_Printf("cmpwi","1,3,%ld",int_val);
  else
    {
-    Inst_Printf("lis","0,%#x",int_val>>16);
-    Inst_Printf("ori","0,0,%#x",int_val & 0xFFFF);
+    Inst_Printf("lis","0,%#lx",int_val>>16);
+    Inst_Printf("ori","0,0,%#lx",int_val & 0xFFFF);
     Inst_Printf("cmpw","1,3,0");
    }
 }
@@ -800,14 +800,14 @@ void Dico_Long(char *name,int global,VType vtype,long value)
      case ARRAY_SIZE:
          if (!global)
              Inst_Printf(".local","%s",name);
-         Inst_Printf(".comm","%s,%d,4",name,value*4);
+         Inst_Printf(".comm","%s,%ld,4",name,value*4);
          break;
 
      case INITIAL_VALUE:
          if (global)
              Inst_Printf(".globl","%s",name);
          Label_Printf("%s:",name);
-         Inst_Printf(".long","%d",value);
+         Inst_Printf(".long","%ld",value);
          break;
     }
 }
