@@ -400,17 +400,17 @@ void Call_C_Start(char *fct_name,int nb_args)
 /* CALL_C_ARG_INT                                                          */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-int Call_C_Arg_Int(int offset,int int_val)
+int Call_C_Arg_Int(int offset,long int_val)
 
 {
  BEFORE_ARG
 
  if (LITTLE_INT(int_val))
-     Delay_Printf("mov","%d,%s",int_val,r);
+     Delay_Printf("mov","%ld,%s",int_val,r);
  else
     {
-     Delay_Printf("sethi","%%hi(%d),%s",int_val,r);
-     Delay_Printf("or","%s,%%lo(%d),%s",r,int_val,r);
+     Delay_Printf("sethi","%%hi(%ld),%s",int_val,r);
+     Delay_Printf("or","%s,%%lo(%ld),%s",r,int_val,r);
     }
 
  AFTER_ARG
@@ -735,15 +735,15 @@ void Move_Ret_To_Foreign_D(int index)
 /* CMP_RET_AND_INT                                                         */
 /*                                                                         */
 /*-------------------------------------------------------------------------*/
-void Cmp_Ret_And_Int(int int_val)
+void Cmp_Ret_And_Int(long int_val)
 
 {
  if (LITTLE_INT(int_val))
-     Inst_Printf("cmp","%%o0,%d",int_val);
+     Inst_Printf("cmp","%%o0,%ld",int_val);
  else
     {
-     Inst_Printf("sethi","%%hi(%d),%%o1",int_val);
-     Inst_Printf("or","%%o1,%%lo(%d),%%o1",int_val);
+     Inst_Printf("sethi","%%hi(%ld),%%o1",int_val);
+     Inst_Printf("or","%%o1,%%lo(%ld),%%o1",int_val);
      Inst_Printf("cmp","%%o0,%%o1");
     }
 }
@@ -865,13 +865,13 @@ void Dico_Long(char *name,int global,VType vtype,long value)
      case ARRAY_SIZE:
 #ifdef M_sparc_sunos
          if (!global)
-             Inst_Printf(".reserve",UN "%s,%d,\"bss\",4",name,value*4);
+             Inst_Printf(".reserve",UN "%s,%ld,\"bss\",4",name,value*4);
           else
-             Inst_Printf(".common",UN "%s,%d,\"bss\"",name,value*4);
+             Inst_Printf(".common",UN "%s,%ld,\"bss\"",name,value*4);
 #else
          if (!global)
              Inst_Printf(".local",UN "%s",name);
-         Inst_Printf(".common",UN "%s,%d,4",name,value*4);
+         Inst_Printf(".common",UN "%s,%ld,4",name,value*4);
 #endif
          break;
 
@@ -884,9 +884,9 @@ void Dico_Long(char *name,int global,VType vtype,long value)
              Inst_Printf(".global",UN "%s",name);
          Label_Printf(UN "%s:",name);
 #ifdef M_sparc_sunos
-         Inst_Printf(".word","%d",value);
+         Inst_Printf(".word","%ld",value);
 #else
-         Inst_Printf(".uaword","%d",value);
+         Inst_Printf(".uaword","%ld",value);
 #endif
          break;
     }
