@@ -35,7 +35,15 @@
 #include "bt_string.c"
 #include "../TopComp/copying.c"
 
+#if 0
+#define CHECK_PRINTF_ARGS
+#endif
 
+#ifdef CHECK_PRINTF_ARGS
+#define GCCPRINTF(x) __attribute__((format(printf,x,x+1)))
+#else
+#define GCCPRINTF(x)
+#endif
 
 
 /*---------------------------------*/
@@ -83,8 +91,8 @@
 typedef struct swt_elt
     {
      BTNode  *atom;         
-     int      n;
-     int      label;
+     long     n;
+     long     label;
     }SwtElt;
 
 
@@ -165,7 +173,7 @@ int       nb_swt_tbl=0;
 Pred     *cur_pred;
 int       cur_pred_no=0;
 int       cur_arity;
-int       cur_sub_label;
+long      cur_sub_label;
 
 int       cur_direct_no=0;
 
@@ -173,6 +181,7 @@ char     *foreign_tbl[FOREIGN_TBL_SIZE];
 
 
 
+
 /*---------------------------------*/
 /* Function Prototypes             */
 /*---------------------------------*/
@@ -185,8 +194,8 @@ void      Compute_Hexa          (char *str,char *hexa);
 void      Emit_Obj_Initializer  (void);
 void      Emit_Exec_Directives  (void);
 void      Emit_One_Atom         (int no,char *str);
-void      Label_Printf          (char *label,...);
-void      Inst_Printf           (char *op,char *operands,...);
+void      Label_Printf          (char *label,...) GCCPRINTF(1);
+void      Inst_Printf           (char *op,char *operands,...) GCCPRINTF(2);
 SwtTbl   *Create_Switch_Table   (int type,int nb_elem);
 void      Write_Call_C          (char *fct_name,ArgVal arg[]);
 
@@ -201,12 +210,12 @@ void      Write_Call_C          (char *fct_name,ArgVal arg[]);
 #define DEF_STR(str)          char *str;
 #define DEF_ATOM(atom)        BTNode *atom; char *str_##atom;
 #define DEF_PRED(hexa)        char *hexa=buff_hexa; char *str_##hexa;
-#define DEF_INTEGER(n)        int n;
+#define DEF_INTEGER(n)        long n;
 #define DEF_FLOAT(n)          double n;
-#define DEF_X_Y(xy)           int xy; char c;
+#define DEF_X_Y(xy)           long xy; char c;
 #define DEF_F_N(atom,n)       DEF_ATOM(atom) DEF_INTEGER(n)
 #define DEF_P_N(hexa,n)       DEF_PRED(hexa) DEF_INTEGER(n)
-#define DEF_LABEL(l)          char l[MAX_LABEL_LENGTH]; int val_##l;
+#define DEF_LABEL(l)          char l[MAX_LABEL_LENGTH]; long val_##l;
 
 
 #define LOAD_STR(str)         Get_Arg(top,char *,str);
@@ -215,15 +224,15 @@ void      Write_Call_C          (char *fct_name,ArgVal arg[]);
 #define LOAD_PRED(hexa)       Get_Arg(top,char *,str_##hexa); \
                               Compute_Hexa(str_##hexa,buff_hexa);
 
-#define LOAD_INTEGER(n)       Get_Arg(top,int,n);
+#define LOAD_INTEGER(n)       Get_Arg(top,long,n);
 #define LOAD_FLOAT(n)         Get_Arg(top,double,n);
 
-#define LOAD_X_Y(xy)          Get_Arg(top,int,xy); \
+#define LOAD_X_Y(xy)          Get_Arg(top,long,xy); \
                               if (xy<5000) c='X'; else xy-=5000, c='Y';
 #define LOAD_F_N(atom,n)      LOAD_ATOM(atom) LOAD_INTEGER(n)
 #define LOAD_P_N(hexa,n)      LOAD_PRED(hexa) LOAD_INTEGER(n)
 
-#define LOAD_LABEL(l)         Get_Arg(top,int,val_##l); \
+#define LOAD_LABEL(l)         Get_Arg(top,long,val_##l); \
                               if (val_##l==-1) strcpy(l,"0"); \
                               else sprintf(l,FORMAT_LABEL(val_##l));
 
@@ -245,8 +254,8 @@ void      Write_Call_C          (char *fct_name,ArgVal arg[]);
 
 
 
-#define FORMAT_LABEL(l)       "Lpred%d_%d",cur_pred_no,(l)
-#define FORMAT_SUB_LABEL(sl)  "Lpred%d_sub_%d",cur_pred_no,(sl)
+#define FORMAT_LABEL(l)       "Lpred%d_%ld",cur_pred_no,(l)
+#define FORMAT_SUB_LABEL(sl)  "Lpred%d_sub_%ld",cur_pred_no,(sl)
 
 
 
@@ -369,8 +378,8 @@ void Emit_Obj_Initializer(void)
                         {
                          sprintf(l,FORMAT_LABEL(t->elem[j].label));
                          Inst_Printf("call_c",
-                           "Create_Swt_Atm_Element(st(%d),%d,at(%d),&%s)",
-                           t->tbl_no,t->nb_elem,(t->elem[j].atom)->no,l);
+                          "Create_Swt_Atm_Element(st(%d),%d,at(%d),&%s)",
+                          t->tbl_no,t->nb_elem,(t->elem[j].atom)->no,l);
                         }
                      break;
 #ifdef SWT_INT_NO_OPT
@@ -379,8 +388,8 @@ void Emit_Obj_Initializer(void)
                         {
                          sprintf(l,FORMAT_LABEL(t->elem[j].label));
                          Inst_Printf("call_c",
-                           "Create_Swt_Int_Element(st(%d),%d,%d,&%s)",
-                           t->tbl_no,t->nb_elem,t->elem[j].n,l);
+                          "Create_Swt_Int_Element(st(%d),%d,%ld,&%s)",
+                          t->tbl_no,t->nb_elem,t->elem[j].n,l);
                         }
                      break;
 #endif
@@ -389,9 +398,9 @@ void Emit_Obj_Initializer(void)
                         {
                          sprintf(l,FORMAT_LABEL(t->elem[j].label));
                          Inst_Printf("call_c",
-                           "Create_Swt_Stc_Element(st(%d),%d,at(%d),%d,&%s)",
-                           t->tbl_no,t->nb_elem,(t->elem[j].atom)->no,
-                           t->elem[j].n,l);
+                          "Create_Swt_Stc_Element(st(%d),%d,at(%d),%ld,&%s)",
+                          t->tbl_no,t->nb_elem,(t->elem[j].atom)->no,
+                          t->elem[j].n,l);
                         }
                 }
             }
@@ -615,7 +624,7 @@ void Ensure_Linked(ArgVal arg[])
     {
      LOAD_PRED(hexa);
      LOAD_INTEGER(n)
-     Inst_Printf("pl_jump","%s_%d",hexa,n);
+     Inst_Printf("pl_jump","%s_%ld",hexa,n);
     }
 
 }
@@ -677,7 +686,7 @@ void F_get_variable(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("move","X(%d),%c(%d)",a,c,xy);
+ Inst_Printf("move","X(%ld),%c(%ld)",a,c,xy);
 }
 
 
@@ -691,7 +700,7 @@ void F_get_value(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("call_c","Unify(%c(%d),X(%d))",c,xy,a);
+ Inst_Printf("call_c","Unify(%c(%ld),X(%ld))",c,xy,a);
  Inst_Printf("fail_ret","");
 }
 
@@ -706,7 +715,7 @@ void F_get_atom(ArgVal arg[])
 
 {
  Args2(ATOM(atom),INTEGER(a))
- Inst_Printf("call_c","Get_Atom(at(%d),X(%d))",atom->no,a);
+ Inst_Printf("call_c","Get_Atom(at(%d),X(%ld))",atom->no,a);
  Inst_Printf("fail_ret","");
 }
 
@@ -721,7 +730,7 @@ void F_get_integer(ArgVal arg[])
 
 {
  Args2(INTEGER(n),INTEGER(a))
- Inst_Printf("call_c","Get_Integer(%d,X(%d))",n,a);
+ Inst_Printf("call_c","Get_Integer(%ld,X(%ld))",n,a);
  Inst_Printf("fail_ret","");
 }
 
@@ -736,7 +745,7 @@ void F_get_float(ArgVal arg[])
 
 {
  Args2(FLOAT(n),INTEGER(a))
- Inst_Printf("call_c","Get_Float(%1.20e,X(%d))",n,a);
+ Inst_Printf("call_c","Get_Float(%1.20e,X(%ld))",n,a);
  Inst_Printf("fail_ret","");
 }
 
@@ -751,7 +760,7 @@ void F_get_nil(ArgVal arg[])
 
 {
  Args1(INTEGER(a))
- Inst_Printf("call_c","Get_Nil(X(%d))",a);
+ Inst_Printf("call_c","Get_Nil(X(%ld))",a);
  Inst_Printf("fail_ret","");
 }
 
@@ -766,7 +775,7 @@ void F_get_list(ArgVal arg[])
 
 {
  Args1(INTEGER(a))
- Inst_Printf("call_c","Get_List(X(%d))",a);
+ Inst_Printf("call_c","Get_List(X(%ld))",a);
  Inst_Printf("fail_ret","");
 }
 
@@ -781,7 +790,7 @@ void F_get_structure(ArgVal arg[])
 
 {
  Args2(F_N(atom,n),INTEGER(a))
- Inst_Printf("call_c","Get_Structure(at(%d),%d,X(%d))",atom->no,n,a);
+ Inst_Printf("call_c","Get_Structure(at(%d),%ld,X(%ld))",atom->no,n,a);
  Inst_Printf("fail_ret","");
 }
 
@@ -799,13 +808,13 @@ void F_put_variable(ArgVal arg[])
  if (c=='X')
     {
      Inst_Printf("call_c","Put_X_Variable()");
-     Inst_Printf("move_ret","X(%d)",a);
-     Inst_Printf("move","X(%d),X(%d)",a,xy);
+     Inst_Printf("move_ret","X(%ld)",a);
+     Inst_Printf("move","X(%ld),X(%ld)",a,xy);
     }
   else
     {
-     Inst_Printf("call_c","Put_Y_Variable(&Y(%d))",xy);
-     Inst_Printf("move_ret","X(%d)",a);
+     Inst_Printf("call_c","Put_Y_Variable(&Y(%ld))",xy);
+     Inst_Printf("move_ret","X(%ld)",a);
     }
 }
 
@@ -821,7 +830,7 @@ void F_put_void(ArgVal arg[])
 {
  Args1(INTEGER(a))
  Inst_Printf("call_c","Put_X_Variable()");
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -835,7 +844,7 @@ void F_put_value(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("move","%c(%d),X(%d)",c,xy,a);
+ Inst_Printf("move","%c(%ld),X(%ld)",c,xy,a);
 }
 
 
@@ -849,8 +858,8 @@ void F_put_unsafe_value(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("call_c","Put_Unsafe_Value(%c(%d))",c,xy);
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("call_c","Put_Unsafe_Value(%c(%ld))",c,xy);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -865,7 +874,7 @@ void F_put_atom(ArgVal arg[])
 {
  Args2(ATOM(atom),INTEGER(a))
  Inst_Printf("call_c","Put_Atom(at(%d))",atom->no);
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -879,8 +888,8 @@ void F_put_integer(ArgVal arg[])
 
 {
  Args2(INTEGER(n),INTEGER(a))
- Inst_Printf("call_c","Put_Integer(%d)",n);
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("call_c","Put_Integer(%ld)",n);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -895,7 +904,7 @@ void F_put_float(ArgVal arg[])
 {
  Args2(FLOAT(n),INTEGER(a))
  Inst_Printf("call_c","Put_Float(%1.20e)",n);
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -910,7 +919,7 @@ void F_put_nil(ArgVal arg[])
 {
  Args1(INTEGER(a))
  Inst_Printf("call_c","Put_Nil()");
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -925,7 +934,7 @@ void F_put_list(ArgVal arg[])
 {
  Args1(INTEGER(a))
  Inst_Printf("call_c","Put_List()");
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -939,8 +948,8 @@ void F_put_structure(ArgVal arg[])
 
 {
  Args2(F_N(atom,n),INTEGER(a))
- Inst_Printf("call_c","Put_Structure(at(%d),%d)",atom->no,n);
- Inst_Printf("move_ret","X(%d)",a);
+ Inst_Printf("call_c","Put_Structure(at(%d),%ld)",atom->no,n);
+ Inst_Printf("move_ret","X(%ld)",a);
 }
 
 
@@ -954,7 +963,7 @@ void F_math_load_value(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("call_c","Math_Load_Value(%c(%d),&X(%d))",c,xy,a);
+ Inst_Printf("call_c","Math_Load_Value(%c(%ld),&X(%ld))",c,xy,a);
 }
 
 
@@ -968,7 +977,7 @@ void F_math_fast_load_value(ArgVal arg[])
 
 {
  Args2(X_Y(xy),INTEGER(a))
- Inst_Printf("call_c","Math_Fast_Load_Value(%c(%d),&X(%d))",c,xy,a);
+ Inst_Printf("call_c","Math_Fast_Load_Value(%c(%ld),&X(%ld))",c,xy,a);
 }
 
 
@@ -983,7 +992,7 @@ void F_unify_variable(ArgVal arg[])
 {
  Args1(X_Y(xy))
  Inst_Printf("call_c","Unify_Variable()");
- Inst_Printf("move_ret","%c(%d)",c,xy);
+ Inst_Printf("move_ret","%c(%ld)",c,xy);
 }
 
 
@@ -997,7 +1006,7 @@ void F_unify_void(ArgVal arg[])
 
 {
  Args1(INTEGER(n))
- Inst_Printf("call_c","Unify_Void(%d)",n);
+ Inst_Printf("call_c","Unify_Void(%ld)",n);
 }
 
 
@@ -1011,7 +1020,7 @@ void F_unify_value(ArgVal arg[])
 
 {
  Args1(X_Y(xy))
- Inst_Printf("call_c","Unify_Value(%c(%d))",c,xy);
+ Inst_Printf("call_c","Unify_Value(%c(%ld))",c,xy);
  Inst_Printf("fail_ret","");
 }
 
@@ -1026,7 +1035,7 @@ void F_unify_local_value(ArgVal arg[])
 
 {
  Args1(X_Y(xy))
- Inst_Printf("call_c","Unify_Local_Value(%c(%d))",c,xy);
+ Inst_Printf("call_c","Unify_Local_Value(%c(%ld))",c,xy);
  Inst_Printf("fail_ret","");
 }
 
@@ -1056,7 +1065,7 @@ void F_unify_integer(ArgVal arg[])
 
 {
  Args1(INTEGER(n))
- Inst_Printf("call_c","Unify_Integer(%d)",n);
+ Inst_Printf("call_c","Unify_Integer(%ld)",n);
  Inst_Printf("fail_ret","");
 }
 
@@ -1099,7 +1108,7 @@ void F_unify_structure(ArgVal arg[])
 
 {
  Args1(F_N(atom,n))
- Inst_Printf("call_c","Unify_Structure(at(%d),%d)",atom->no,n);
+ Inst_Printf("call_c","Unify_Structure(at(%d),%ld)",atom->no,n);
  Inst_Printf("fail_ret","");
 }
 
@@ -1114,7 +1123,7 @@ void F_allocate(ArgVal arg[])
 
 {
  Args1(INTEGER(n))
- Inst_Printf("call_c","Allocate(%d)",n);
+ Inst_Printf("call_c","Allocate(%ld)",n);
 }
 
 
@@ -1142,7 +1151,7 @@ void F_call(ArgVal arg[])
 {
  Args1(P_N(hexa,n))
 
- Inst_Printf("pl_call","%s_%d",hexa,n);
+ Inst_Printf("pl_call","%s_%ld",hexa,n);
 }
 
 
@@ -1157,7 +1166,7 @@ void F_execute(ArgVal arg[])
 {
  Args1(P_N(hexa,n))
 
- Inst_Printf("pl_jump","%s_%d",hexa,n);
+ Inst_Printf("pl_jump","%s_%ld",hexa,n);
 }
 
 
@@ -1330,7 +1339,7 @@ void F_switch_on_integer(ArgVal arg[])
     {
      LOAD_INTEGER(n);
      LOAD_LABEL(l);
-     fprintf(file_out,"%c%d=%s",c,n,l);
+     fprintf(file_out,"%c%ld=%s",c,n,l);
      c=',';
     }
  fprintf(file_out,")\n");
@@ -1481,7 +1490,7 @@ void F_load_cut_level(ArgVal arg[])
 
 {
  Args1(INTEGER(a))
- Inst_Printf("call_c","Load_Cut_Level(&X(%d))",a);
+ Inst_Printf("call_c","Load_Cut_Level(&X(%ld))",a);
  cur_arity=a+1;                       /* to save X(a) in backatrack points */
 }
 
@@ -1496,7 +1505,7 @@ void F_cut(ArgVal arg[])
 
 {
  Args1(X_Y(xy))
- Inst_Printf("call_c","Cut(%c(%d))",c,xy);
+ Inst_Printf("call_c","Cut(%c(%ld))",c,xy);
 }
 
 
@@ -1523,7 +1532,7 @@ void Write_Call_C(char *fct_name,ArgVal arg[])
      if (i>0)
          fputc(',',file_out);
      LOAD_INTEGER(n)
-     fprintf(file_out,"X(%d)",n);
+     fprintf(file_out,"X(%ld)",n);
     }
 
  fprintf(file_out,")\n");
@@ -1542,7 +1551,7 @@ void F_function(ArgVal arg[])
  Args2(STR(name),INTEGER(x))
 
  Write_Call_C(name,top);
- Inst_Printf("move_ret","X(%d)",x);
+ Inst_Printf("move_ret","X(%ld)",x);
 }
 
 
@@ -1679,16 +1688,16 @@ void F_foreign_call_c(ArgVal arg[])
 
  if (chc_size>=0)
     {
-     sprintf(l,FORMAT_LABEL(1));
-     Inst_Printf("call_c","Foreign_Create_Choice(&%s,%d,%d)",
+     sprintf(l,FORMAT_LABEL(1L));
+     Inst_Printf("call_c","Foreign_Create_Choice(&%s,%d,%ld)",
                            l,cur_arity,chc_size);
      Label_Printf("%s:",l);
-     Inst_Printf("call_c","Foreign_Update_Choice(&%s,%d,%d)",
+     Inst_Printf("call_c","Foreign_Update_Choice(&%s,%d,%ld)",
                            l,cur_arity,chc_size);
     }
 
  if (*bip_name || bip_arity!= -2)
-     Inst_Printf("call_c","Set_C_Bip_Name(\"%s\",%d)",
+     Inst_Printf("call_c","Set_C_Bip_Name(\"%s\",%ld)",
                  bip_name,bip_arity);
 
  for(i=0;i<nb_elem;i++)
