@@ -178,7 +178,7 @@ char     *cur_line_p;
 char     *beg_last_token;
 
 char      str_val[MAX_STR_LEN];
-int       int_val;
+long      int_val;
 double    dbl_val;
 
 
@@ -437,7 +437,7 @@ static void Read_Argument(int arg_type,ArgVal **top)
 
      case INTEGER:
          Read_Token(INTEGER);
-         Add_Arg(*top,int,int_val);
+         Add_Arg(*top,long,int_val);
          break;
 
      case FLOAT:
@@ -452,9 +452,9 @@ static void Read_Argument(int arg_type,ArgVal **top)
              Syntax_Error("x(...) or y(...) expected");
          Read_Token('('); Read_Token(INTEGER); Read_Token(')');
          if (*str_val=='x')
-             Add_Arg(*top,int,int_val);
+             Add_Arg(*top,long,int_val);
           else
-             Add_Arg(*top,int,5000+int_val);
+             Add_Arg(*top,long,5000+int_val);
          break;
 
      case F_N:
@@ -470,14 +470,14 @@ static void Read_Argument(int arg_type,ArgVal **top)
               else
                  int_val=-1;
             }
-         Add_Arg(*top,int,int_val);
+         Add_Arg(*top,long,int_val);
          break;
 
      case LST_INTEGER:
      case LST_F_N:
          arg_type=arg_type-LST_INTEGER+INTEGER;
          top1= *top;
-         Add_Arg(*top,int,0);            /* reserve space for case counter */
+         Add_Arg(*top,long,0);           /* reserve space for case counter */
          n=0;
          k=Scanner(1);
          if (k==ATOM && strcmp(str_val,"[]")==0)             /* empty list */
@@ -495,13 +495,13 @@ static void Read_Argument(int arg_type,ArgVal **top)
              if (k!=',')
                  Syntax_Error("] or , expected");
 	    }
-         Add_Arg(top1,int,n);
+         Add_Arg(top1,long,n);
          break;
 
      default:               /*  LST_x_INTEGER with x in (ATOM,INTEGER,F_N) */
          arg_type=arg_type-LST_ATOM_INTEGER+ATOM;
          top1= *top;
-         Add_Arg(*top,int,0);            /* reserve space for case counter */
+         Add_Arg(*top,long,0);           /* reserve space for case counter */
          n=0;
          k=Scanner(1);
          if (k==ATOM && strcmp(str_val,"[]")==0)             /* empty list */
@@ -523,7 +523,7 @@ static void Read_Argument(int arg_type,ArgVal **top)
              if (k!=',')
                  Syntax_Error("] or , expected");
 	    }
-         Add_Arg(top1,int,n);
+         Add_Arg(top1,long,n);
          break;
     }
 }
@@ -585,7 +585,7 @@ static int Scanner(int complex_atom)
 
 {
  char   *p,*p1;
- int     i;
+ long    i;
  double  d;
  double  strtod();
 
@@ -659,7 +659,7 @@ static int Scanner(int complex_atom)
                      i=8;
                  i=strtol(cur_line_p,&p1,i);      /* stop on the closing \ */
                  cur_line_p=p1+1;
-                 sprintf(p,"%03o",i);
+                 sprintf(p,"%03lo",i);
                  p+=3;
                 }
             }
