@@ -41,7 +41,7 @@
 
 void      Source_Line           (int line_no,char *cmt);
 void      Prolog_File_Name      (char *pl_file);
-void      New_Predicate         (char *functor,int pl_line,int arity,
+void      New_Predicate         (char *functor,int arity,int pl_line,
                                  int dynamic,int public,
                                  int built_in,int built_in_fd);
 void      New_Directive         (int pl_line,int system);
